@@ -72,7 +72,7 @@ def open_network_environment_files(netenv_path, template_files):
     errors = []
 
     try:
-        network_data = yaml.load(template_files[netenv_path])
+        network_data = yaml.safe_load(template_files[netenv_path])
     except Exception as e:
         return ({}, {}, ["Can't open network environment file '{}': {}"
                          .format(netenv_path, e)])
@@ -85,7 +85,7 @@ def open_network_environment_files(netenv_path, template_files):
             try:
                 nic_configs.append((
                     nic_name, nic_config_path,
-                    yaml.load(template_files[nic_config_path])))
+                    yaml.safe_load(template_files[nic_config_path])))
             except Exception as e:
                 errors.append(
                     "Can't open the resource '{}' reference file '{}': {}"
@@ -265,6 +265,8 @@ def check_allocation_pools_pairing(filedata, pools):
             errors.append('The IP ranges in {} must form a list.'
                           .format(poolitem))
             continue
+
+        # Check IP range format
         for dict_range in pooldata:
             try:
                 pool_objs.append(netaddr.IPRange(
@@ -275,6 +277,7 @@ def check_allocation_pools_pairing(filedata, pools):
                               .format(poolitem, dict_range))
                 continue
 
+        # Check if CIDR is specified and IP network is valid
         subnet_item = poolitem.split('AllocationPools')[0] + 'NetCidr'
         try:
             network = filedata[subnet_item]
@@ -287,15 +290,23 @@ def check_allocation_pools_pairing(filedata, pools):
             errors.append('Invalid IP network: {}'.format(network))
             continue
 
-        for ranges in pool_objs:
-            for range in ranges:
-                if range not in subnet_obj:
-                    errors.append('Allocation pool {} {} outside of subnet'
-                                  ' {}: {}'.format(poolitem,
-                                                   pooldata,
-                                                   subnet_item,
-                                                   subnet_obj))
+        for range in pool_objs:
+            # Check if pool is included in subnet
+            if range not in subnet_obj:
+                errors.append('Allocation pool {} {} outside of subnet'
+                              ' {}: {}'.format(poolitem,
+                                               pooldata,
+                                               subnet_item,
+                                               subnet_obj))
+                break
+
+            # Check for overlapping pools
+            for other in [r for r in pool_objs if r != range]:
+                if range.first in other or range.last in other:
+                    errors.append('Some pools in {} are overlapping.'.format(
+                                  poolitem))
                     break
+
     return errors
 
 
@@ -460,8 +471,8 @@ def duplicate_static_ips(static_ips):
 
 def validate_node_pool_size(plan_env_path, ip_pools_path, template_files):
     warnings = []
-    plan_env = yaml.load(template_files[plan_env_path])
-    ip_pools = yaml.load(template_files[ip_pools_path])
+    plan_env = yaml.safe_load(template_files[plan_env_path])
+    ip_pools = yaml.safe_load(template_files[ip_pools_path])
 
     param_defaults = plan_env.get('parameter_defaults')
     node_counts = {
